function fit = func(x, fun0,~)
% Benchmark functions 
% INPUTS:
% -  x is a D-element row vector representing the candidate solution we want
%	 to evaluate, where D is the problem dimension
% -  fun is the index of the function of interest
% -  ~ is for opt_f, the minimum function value to try to reach. Not used here
%				but kept for consistency with some other benchmarks

% OUTPUT:
% -  fit is the fitness of x (i.e. fit = f(x))
global a % Just for tests

	[~,D]=size(x);
	x=x';

    if fun0 >1000 && fun0 <2151 % Lennard-Jones
    	fun=5;
    else fun=fun0;
    end

switch fun
		case -4 % Needle (Parabola with plateau around)
		posMin=0.3*ones(1,D);
		width=0.001;
		r= pdist([x';posMin],'euclidean');
		if r<=width
			fit=r^2;
		else
			fit=width^2;
		end
	

		case -3 % Picece-wise linear
		if ~exist('a','var') a=0.3; end
		if x<a
			fit=(a-x)/a;
		else
			fit=(x-a)/(1-a);
		end

		case -2 % Line
		fit=1-x;
		%fit=x;
		
		case -1 % Impossible Plateau
		fit=1;

		case 0 % Paraboloid
%						Solution on (1, 2, 3, ..., D)
		fit=0;
		for d=1:D
			fit=fit+(x(d)-d)^2;
		end

    case 1 % Alpine. Minimum (1,2,...,D)
    	for d=1:D 
    		xd(d)=x(d)-d; 
    	end
        fit = sum(abs(xd.*sin(xd)) + 0.1*abs(xd));
     
    case 2 % Tripod. Minimum (0, -50)		     			
    x1 = x(1) ; 
    x2 = x(2);
      
if x2<0
      fit=abs(x1)+abs(x2+50);
else
	 	if x1 < 0 
 			fit=1 + abs(x1+50) + abs(x2- 50);
		else 
			fit=2 + abs(x1-50) + abs(x2-50);
		end
end
     	case 3 % Gear train
     	z=1.0/6.931;
     	fit=z-x(1)*x(2)/(x(3)*x(4));
  		fit=fit*fit;
  
  		case 4 % Pressure vessel
  		fit=0.6224*x(1)*x(3)*x(4) + 1.7781*x(2)*x(3)*x(3) ...
  				+ x(1)*x(1)*(3.1611*x(4) +19.84*x(3));
  				
  		% Takes constraints into account (penalty method)
  		g(1)=0.0193*x(3)-x(1);
  		g(2)=0.00954*x(3)-x(2);
  		g(3)=1296000-pi*x(3)*x(3)*(x(4)+4*x(3)/3);
  	
  		pw=10^10;
  		if g(1)>0 c= 1+pw*g(1);  fit=fit*c*c; end
			if g(2)>0 c=1+pw*g(2); fit=fit*c*c;  end
			%if g(2)>0 c=1+g(2); fit=fit*c*c;  end
			if g(3)>0 c=1+pw*g(3); fit=fit*c*c;  end
			%if g(3)>0 c=1+g(3); fit=fit*c*c;  end
			
			case 5 % Lennard-Jones
			fit=lennardJones(x);
			
			case 6 % Flash
			c1=0.1;  
    c2=0.5;
    u1=x(1);
    if u1<2*c1 | u1>5*c1  fit=c2;
    else
      u2=u1-2*c1;
      if u2<=c1 fit=c2*(1-u2/c1);
      else
        u3=u1-3*c1;
        if u3<c1  fit=u3/c1;
        else
          u4=u1-4*c1;
          fit=1-c2*u4/c1;
        end
      end
    end
			
			case 7 % Comb
			c1=10; 
    c2=1;
    u=x(1);
    fit=1+sin(c1*u) +u/c1;
    fit=min(fit,c2);
			
			case 8 % Brush
			c1=10; c2=1;
    fit=0;
    for d=1:D
      xs=x(d)-d;
      fit=fit+abs(xs*sin(c1*xs))+abs(xs)/c1 ;
    end
    fit=min(fit,c2);
    
    case 9 % TSP6
    fit=TSP6eval(x); 
    
    case 10 % Canyon  on [0,10]
    border=9.99;
    if x<border
    	fit=0.8+x*0.2/border;
    else
    	fit=(10-x)/(10-border);
    end
    
    case 11 % Six Hump Camel Back
       x1=x(1); x2=x(2); 
       fit=	(4-2.1*x1^2+x1^4/3)*x1^2+x1*x2+(-4+4*x2^2)*x2^2; 
		
    otherwise
        error('\nNo function %i',fun);
end
end

