function compareResults (qualityCurve,nbBins)
	% Comparaison of the results of several iterative stochastic algorithms
	% on a given problem
	% 2015-09 Maurice.Clerc@WriteMe.com
	%
	% Each experiment has produced a result (one usually keeps the best one)
	% N independent experiments have been lauchend, with the same "budget"
	%		(usually a number of evaluations of the objective function)
	% For each algorithm, these N results are saved on a file, one/line/
	% The file may contain comments, the data begins at row r0
	%
	% WARNING: the number of experiments MUST be the same for all algorithms
	%
	% This script analyses the results to produce a fair comparison,
	% based on the their probabilistic distributions, and not only
	%	as usually, based on (minimum, median, mean(std. dev)).
	%
	% That is why N should be big enough to have good estimations of these
	%	distributions. Typically N>=100.
	
	% qualityCurve  0 Linear
	%								1	Parabolic
	%								2 Normal
	%								3 Exponential
	
	if ~exist('qualityCurve')
		qualityCurve=3;
	end
	
	if ~exist('nbBins')
		nbBins=10;
	end

	
	% Reads the data. 
	%	Of course, you have to modify it according to your own files
%	repertory='./CEC2011_T01_6000/';
%	repertory='./CEC2011_T02_30000/';
%repertory='./CEC2011_T02_13400/';
%repertory='./MyFunctions_1_3400/'
	repertory='./CEC2005_01_10D_7700/'; 
	
	r0=4; % Number of lines to skip (usually comments, with the detailed
%					options and parameter values)

%
algo{1}='APS4_[7]';
algo{2}='APS4_[1 2 7]';


	nbAlgo=length(algo);

	for n=1:nbAlgo
		data{n}=strcat(repertory, algo{n},'.txt');
	end
	
	comparInd=[1 2]; % You may want to compare only some of t										
	% comparInd=[1:nbAlgo];	% If you want to compare all
		nbData=length(comparInd);
		
	mini=Inf; maxi=-Inf;
	
	fprintf('\nAlgorithm              Mini           Median          Mean          Std.dev');
	
	for m=1:nbData
		mm=comparInd(m);
		name=algo{mm};
		results=data{mm};
		R{m}=csvread(results,r0,0);
		miniR=min(R{m}); maxiR=max(R{m});
	 
		fprintf('\n %15s       %1.5e       %1.5e      %1.5e       %1.5e',...
				name,miniR,median(R{m}),mean(R{m}),std(R{m}));
		mini=min(mini,miniR);
		maxi=max(maxi,maxiR);
	end

	%disp([mini, maxi])  % Common minimum and maximum
	score=zeros(nbData,1);
	scoreW=score; % Weighted score
		
	% Builds the CDFs, and plot them
	for m=1:nbData
		CDF{m}=CDFplot(R{m},mini,maxi,nbBins);
	end
	

	%	Builds the comparison table
	% Column	1: the pairs that are compared 
	%	Column	2: weighted difference 
	% Column	3: conclusion (better/worse/equivalent)
	%	Column	4: confidence coefficient
	fprintf('\n\nAlgo                   Algo       Difference')
	fprintf('      Conclusion Confidence');
			
	k=0;
	for m=1:nbData-1
	for m1=m+1:nbData
			k=k+1;

		c{k,1}=[m m1]; 
		c{k,2}=CDF_compare(CDF{m},CDF{m1},0,qualityCurve);
	
	
		% Evaluates the confidence
		countBetter=0; countWorse=0; countEquiv=0;
		nbBins=length(CDF{1}(1,:));
		
		for nb=1:nbBins
			if CDF{m}(2,nb)>CDF{m1}(2,nb) countBetter=countBetter+1; end
			if CDF{m}(2,nb)<CDF{m1}(2,nb) countWorse=countWorse+1; end
			if CDF{m}(2,nb)==CDF{m1}(2,nb) countEquiv=countEquiv+1; end
		end
		
		countBetter=countBetter/nbBins;
		countWorse=countWorse/nbBins;
		countEquiv=countEquiv/nbBins;
		
	if c{k,2}>0 
		if countBetter>0.5
			c{k,3}='better';
			score(m)=score(m)+1;
		else
			c{k,3}='equiv.';
			score(m)=score(m)+1/2;
			score(m1)=score(m1)+1/2;
		end
			
		%	c{k,4}=countBetter;
			
			scoreW(m)=scoreW(m)+c{k,2};
		
		end
		
		if c{k,2}<0 
	%if c{k,2}<-0.5 
	if countWorse>0.5
			c{k,3}='worse';
			score(m1)=score(m1)+1;
		else
			c{k,3}='equiv.';
			score(m)=score(m)+1/2;
			score(m1)=score(m1)+1/2;
		end
		
		%	c{k,4}=countWorse/nbBins;
		
			scoreW(m1)=scoreW(m1)-c{k,2};
		end
		
		if abs(c{k,2})<realmin 
			c{k,3}='equiv.'; 
		%	c{k,4}=countEquiv/nbBins;
			score(m)=score(m)+1/2;
			score(m1)=score(m1)+1/2;
		end	
		

		name1=algo{comparInd(c{k,1}(1,1))}; 
		name2=algo{comparInd(c{k,1}(1,2))};

	%fprintf('%20s  vs   %20s   %1.2f    %s   %1.2f',name1,name2,c{k,2},c{k,3},c{k,4})
		fprintf('\n%15s vs %15s   %1.2f         %s',name1,name2,c{k,2},c{k,3})
		end	% % for m1=1:nbData
	end % for m=1:nbData
	
	fprintf('\n\n        Algorithm        Score  Weighted_score')	
	%scoreW=score.*scoreW/nBins;
	scoreW=100*scoreW/sum(scoreW);
	
	for m=1:nbData
		mm=comparInd(m);
		fprintf('\n%20s     %2.1f    %2.1f', algo{mm},score(m), scoreW(m));
	end	
	fprintf('\n')
end
